#!/bin/csh

if (`flagLoc $argv -help`) then
   echo "List 2D Sizes and Chemical Shift Info:"
   echo " report2D.com inName1 ..."
endif

if ($#argv == 0) then
   exit 0
endif

foreach inName ($*)
   if (!(-e $inName)) then
         nmrPrintf " Is not valid NMRPipe data."
         continue
   endif

   set vInfo = (`showhdr -test $inName` 0 0)

   if ($vInfo[2] == 0) then
      nmrPrintf " Is not valid NMRPipe data."
      continue
   endif
  
   set xSW  = (`getParm -in $inName -fmt %.0f -parm NDSW   -dim CUR_XDIM`)
   set xCAR = (`getParm -in $inName -fmt %.3f -parm NDCAR  -dim CUR_XDIM`)
   set xOBS = (`getParm -in $inName -fmt %.3f -parm NDOBS  -dim CUR_XDIM`)
   set xN   = (`getParm -in $inName -fmt %.0f -parm NDSIZE -dim CUR_XDIM`)
   set xT   = (`getParm -in $inName -fmt %.0f -parm NDAPOD -dim CUR_XDIM`)
   set xP0  = (`getParm -in $inName -fmt %.0f -parm NDP0   -dim CUR_XDIM`)
   set xP1  = (`getParm -in $inName -fmt %.0f -parm NDP1   -dim CUR_XDIM`)

   set ySW  = (`getParm -in $inName -fmt %.0f -parm NDSW   -dim CUR_YDIM`)
   set yCAR = (`getParm -in $inName -fmt %.3f -parm NDCAR  -dim CUR_YDIM`)
   set yOBS = (`getParm -in $inName -fmt %.3f -parm NDOBS  -dim CUR_YDIM`)
   set yN   = (`getParm -in $inName -fmt %.0f -parm NDSIZE -dim CUR_YDIM`)
   set yT   = (`getParm -in $inName -fmt %.0f -parm NDAPOD -dim CUR_YDIM`)
   set yP0  = (`getParm -in $inName -fmt %.0f -parm NDP0   -dim CUR_YDIM`)
   set yP1  = (`getParm -in $inName -fmt %.0f -parm NDP1   -dim CUR_YDIM`)

   nmrPrintf " X-Axis Size: %4d %4d P0: %6.1f P1: %6.1f SW: %7.1f Hz CAR: %7.3f ppm OBS: %7.3f MHz\n" $xT $xN $xP0 $xP1 $xSW $xCAR $xOBS
   nmrPrintf " Y-Axis Size: %4d %4d P0: %6.1f P1: %6.1f SW: %7.1f Hz CAR: %7.3f ppm OBS: %7.3f MHz\n" $yT $yN $yP0 $yP1 $ySW $yCAR $yOBS
end
